#
# spec file for package you-get
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           you-get
Version:        0.4.1743
Release:        1.5
Summary:        Dumb downloader that scrapes the web
License:        MIT
URL:            https://you-get.org
Source0:        https://github.com/soimort/you-get/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  fish
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  zsh
Requires:       ffmpeg
Requires:       python3-dukpy
BuildArch:      noarch

%description
You-Get is a command-line utility to download media contents
(videos, audios, images) from the Web, in case there is no other
handy way to do it.

%package        bash-completion
Summary:        Bash completion for %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description    bash-completion
Bash command line completion support for %{name}.

%package        fish-completion
Summary:        Fish completion for %{name}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description    fish-completion
Fish command line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%prep
%setup -q
# remove shebang
for f in $(find ./src -name "*.py"); do
   sed '0,/^#!/{//d;}' -i ${f}
done
# fix interpreter
sed -i 's|^#!/usr/bin/env python3|#!%{_bindir}/python3|' you-get

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}
install -m0755 you-get %{buildroot}%{_bindir}
%fdupes -s %{buildroot}%{python3_sitelib}
install -Dm644 contrib/completion/you-get-completion.bash %{buildroot}%{_datadir}/bash-completion/completions/you-get
install -Dm644 contrib/completion/you-get.fish %{buildroot}%{_datadir}/fish/completions/you-get.fish
install -Dm644 contrib/completion/_you-get %{buildroot}%{_datadir}/zsh/site-functions/_you-get

%check

%files
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%{_bindir}/you-get
%{python3_sitelib}/*

%files bash-completion
%{_datadir}/bash-completion/completions/you-get

%files fish-completion
%{_datadir}/fish/completions/you-get.fish

%files zsh-completion
%{_datadir}/zsh/site-functions/_you-get

%changelog
* Sat Jan  4 2025 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1743
  * [YouTube] Fix extraction
  * Fix: Restore functionality of -o parameter for Miaopai
    downloads
  * remove imported but unsed module
* Mon Aug 19 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1730
  * [vimeo] cleanup
  * [tests] disable test_youtube temporarily
  * fix "SyntaxWarning: invalid escape sequence" for Python 3.12
  * [youtube] update self.ua (fix extraction)
  * [youtube] add self.ua
  * [tiktok] support short URLs (vt.tiktok.com)
  * Add Flox as an installation option
  * [instagram] fix extraction
  * Add ytInitialPlayerResponse checker to let user easily know
    problem
  * [youtube] sloppy fix
* Sun Jul 14 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1718
  * Makefile: stop using python setup.py commands
  * chore: also include you-get.plugin.zsh and CONTRIBUTING.md
  * [common] update UA
  * [youtube] more detailed logging of stream formats
  * [youtube] separate files for autogenerated caption tracks
  * [youtube] fix extraction
* Tue Jun 25 2024 Luigi Baldoni <aloisio@gmx.com>
- Add missing runtime requirement
* Mon Jun 24 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1710
  * YouTube: Fix 403 error and throttling
* Wed May 22 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1700
  * Bilibili: fix extraction
  * TikTok: fix extraction
  * X (Twitter): fix extraction
* Sun Dec 11 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1650
  * Twitter: support tweets with multiple videos and NSFW tweets.
  * TikTok: fix extraction.
  * YouTube: improve extractor.
* Sat Jul  2 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1620
  * Instagram: fix extraction.
  * YouTube: fix extraction.
  * set the oldest supported python version to 3.7.4
* Mon May 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1612 (no changelog)
* Sat Apr 23 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1602 (no changelog)
* Wed Nov  3 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1555 (no changelog)
* Sun Aug 15 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1545 (no changelog)
* Sun Jul 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1536 (no changelog)
* Tue Jun  1 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1527 (no changelog supplied)
* Mon May 24 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1525 (no changelog supplied)
* Mon Mar 29 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1520 (no changelog supplied)
* Sun Dec 27 2020 aloisio@gmx.com
- Update to version 0.4.1500 (no changelog supplied)
* Thu Nov 19 2020 aloisio@gmx.com
- Update to version 0.4.1488 (no changelog supplied)
* Tue Oct 27 2020 aloisio@gmx.com
- Update to version 0.4.1475 (no changelog supplied)
* Sun Jul 19 2020 aloisio@gmx.com
- Update to version 0.4.1456 (no changelog supplied)
* Mon Mar 30 2020 aloisio@gmx.com
- Update to version 0.4.1432 (no changelog supplied)
* Mon Mar 23 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1423 (no changelog supplied)
* Mon Mar  2 2020 aloisio@gmx.com
- Update to version 0.4.1410 (no changelog supplied)
* Mon Jan 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1403 (no changelog supplied)
* Tue Dec 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Removed groups
* Sat Dec 28 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1388 (no changelog supplied)
* Tue Sep 24 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1355 (no changelog supplied)
* Tue Sep 10 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1347 (no changelog supplied)
* Fri Aug  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1328 (no changelog supplied)
* Tue Jun 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1314 (no changelog supplied)
* Thu May  9 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1302 (no changelog supplied)
* Thu Apr 25 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1295 (no changelog supplied)
* Sat Mar  9 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1270 (no changelog supplied)
* Wed Feb 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1256 (no changelog supplied)
* Sat Feb 16 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1210 (no changelog supplied)
* Fri Jan 18 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1205 (no changelog supplied)
* Mon Dec 17 2018 aloisio@gmx.com
- Update to version 0.4.1193 (no changelog supplied)
* Sat Dec  1 2018 aloisio@gmx.com
- Update to version 0.4.1181 (no changelog supplied)
* Wed Nov  7 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1167 (no changelog supplied)
* Mon Oct 29 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1164 (no changelog supplied)
* Thu Oct 11 2018 Luigi Baldoni <aloisio@gmx.com>
- Use upstream exe script to avoid runtime dependency on
  setuptools
* Wed Sep 12 2018 aloisio@gmx.com
- Update to version 0.4.1148 (no changelog supplied)
* Sat Sep  8 2018 aloisio@gmx.com
- Update to version 0.4.1140 (no changelog supplied)
* Fri Aug 10 2018 aloisio@gmx.com
- Update to version 0.4.1128 (no changelog supplied)
* Wed Aug  8 2018 aloisio@gmx.com
- Update to version 0.4.1120 (no changelog supplied)
* Thu Jun 28 2018 aloisio@gmx.com
- Update to version 0.4.1099 (no changelog supplied)
* Tue May 15 2018 aloisio@gmx.com
- Update to version 0.4.1077 (no changelog supplied)
* Mon Apr 16 2018 aloisio@gmx.com
- Update to version 0.4.1060 (no changelog supplied)
* Fri Mar  2 2018 aloisio@gmx.com
- Update to version 0.4.1040 (no changelog supplied)
* Fri Feb  9 2018 aloisio@gmx.com
- Update to version 0.4.1025 (no changelog supplied)
* Sat Dec 23 2017 aloisio@gmx.com
- Update to version 0.4.1011 (no changelog supplied)
* Sun Dec 10 2017 jengelh@inai.de
- Update RPM groups. Fix size estimate in description.
* Mon Dec  4 2017 aloisio@gmx.com
- Update to version 0.4.995 (no changelog supplied)
* Sat Dec  2 2017 aloisio@gmx.com
- Update to version 0.4.990 (no changelog supplied)
* Tue Nov 28 2017 aloisio@gmx.com
- Update to version 0.4.985
* Sat Nov 18 2017 aloisio@gmx.com
- Initial package (0.4.964)
